<template>
  <div>
    <el-dialog v-loading="diaLoading" :close-on-click-modal="false"
               :close-on-press-escape="false"
               :visible.sync="formDia"
               title="量值溯源计划"
               width="80%" @close="closeFormDia">
      <el-form ref="form" :model="form" :rules="rules" label-position="right" label-width="auto">
        <el-row :gutter="20">
          <el-col :span="12">
            <el-form-item label="仪器名称" prop="instrumentName">
              <el-input v-model="form.instrumentName" clearable size="small"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="规格型号" prop="model">
              <el-input v-model="form.model" clearable size="small"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="管理编号" prop="managementNumber">
              <el-input v-model="form.managementNumber" clearable size="small"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="技术指标" prop="technicalIndicators">
              <el-input v-model="form.technicalIndicators" clearable size="small"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="检定周期" prop="verificationCyde">
              <el-input v-model="form.verificationCyde" clearable size="small"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="检定单位" prop="verificationUnit">
              <el-input v-model="form.verificationUnit" clearable size="small"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="最近检定日期" prop="recentlyTime">
              <el-date-picker
                v-model="form.recentlyTime"
                clearable
                format="yyyy-MM-dd HH:mm:ss" placeholder="选择日期"
                size="small" style="width: 100%"
                type="datetime" value-format="yyyy-MM-dd HH:mm:ss">
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="计划下次检定日期" prop="nextTime">
              <el-date-picker
                v-model="form.nextTime"
                clearable
                format="yyyy-MM-dd HH:mm:ss" placeholder="选择日期"
                size="small" style="width: 100%"
                type="datetime" value-format="yyyy-MM-dd HH:mm:ss">
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="备注" prop="remark">
              <el-input v-model="form.remark" clearable size="small"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button @click="closeFormDia">取 消</el-button>
        <el-button :loading="loading" type="primary" @click="handleEdit">提 交</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
export default {
  name: "formDia",
  // import 引入的组件需要注入到对象中才能使用
  components: {},
  data () {
    // 这里存放数据
    return {
      formDia: false,
      diaLoading: false,
      loading: false,
      form: {
        instrumentName: '',
        model: '',
        managementNumber: '',
        technicalIndicators: '',
        verificationCyde: '',
        verificationUnit: '',
        recentlyTime: '',
        nextTime: '',
        remark: '',
        id: '',
      },
      rules: {
        instrumentName: [{required: true, message: '请填写仪器名称',trigger: 'blur'}],
        model: [{required: true, message: '请填写规格型号',trigger: 'blur'}],
        managementNumber: [{required: true, message: '请填写管理编号',trigger: 'blur'}],
        technicalIndicators: [{required: true, message: '请填写技术指标',trigger: 'blur'}],
        verificationCyde: [{required: true, message: '请填写检定周期',trigger: 'blur'}],
        verificationUnit: [{required: true, message: '请填写检定单位',trigger: 'blur'}],
        recentlyTime: [{required: true, message: '请选择最近检定日期',trigger: 'change'}],
        nextTime: [{required: true, message: '请选择计划下次检定日期',trigger: 'change'}],
      },
      operationType: '',
    }
  },
  mounted() {

  },
  // 方法集合
  methods: {
// 打开弹框
    openDia (type, row) {
      this.formDia = true
      this.operationType = type
      if (type !== 'add') {
        this.form = row
      }
    },
    // 提交弹框数据
    handleEdit () {
      this.$refs['form'].validate((valid) => {
        if (valid) {
          this.loading = true
          const internalReport = this.HaveJson(this.form)
          this.$axios.post(this.$api.feCalibrationSchedule.addCalibrationSchedule, internalReport, {
            headers: {
              "Content-Type": "application/json"
            },
            noQs: true
          }).then(res => {
            this.loading = false
            if (res.code === 201) return
            this.$message.success('操作成功')
            this.closeFormDia()
          }).catch(err => {
            console.log('err---', err);
            this.loading = false
          })
        } else {
          console.log('error submit!!');
          return false;
        }
      });
    },
    closeFormDia () {
      this.$refs.form.resetFields();
      this.formDia = false
      this.$emit('closeFormDia')
    },
  },
}
</script>

<style scoped>
</style>
